==> tkScenarist-1.0.5.tar.gz: tkScenarist-1.0.5/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(

    name="tkScenarist",

    version="1.0.5",            # must be PEP 440 compliant by now!

    packages=find_packages(),
    scripts=["bin/tkscenarist"],
    requires=["Tkinter"],
    description="tkScenarist - screen writing made simpler",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/tkScenarist/wiki",
    download_url="https://github.com/tarball69/tkScenarist/releases",
    keywords=["scenario", "scenarist", "script", "writer",
    "storyboard", "character", "movie"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Topic :: Artistic Software",
        "Topic :: Text Editors",
        "Topic :: Text Editors :: Documentation",
        "Topic :: Utilities",
    ],
    license="Licensed under GNU General Public License v3.",
    long_description="""

tkScenarist - screen writing made simpler
-----------------------------------------

**tkScenarist** is a simple Python3/Tkinter application aiming to make
movie screen writing simpler for scenarists.

**CAUTION**: minimum requirements are Python >= 3.3 with its dedicated
Tkinter GUI library (Tcl >= 8.5).

This software is a **freefullware** (see below).


What's new?
-----------

* trying to make tkScenarist distributable through pip tool.


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free;

Just get it and enjoy.

That's all, folks!


Documentation
-------------

Please, feel free to visit our wiki wiki online documentation at:

https://github.com/tarball69/tkScenarist/wiki

No answer in documentation? Request for help on our mailing list:

https://mail.python.org/mailman/listinfo/tkscenarist-help


MS-Windows users
----------------

MS-Windows users may find a `setup.exe` file at:

https://github.com/tarball69/tkScenarist/tree/master/win32setup

First, click on given file name/version then click on `Raw` button to
download it.

"""

) # end setup

==> tkScenarist-1.1.3.tar.gz: tkScenarist-1.1.3/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(

    name="tkScenarist",

    version="1.1.3",            # must be PEP 440 compliant by now!

    packages=find_packages(),
    include_package_data=True,
    scripts=["bin/tkscenarist.sh", "bin/tkscenarist.bat"],
    requires=["Tkinter"],
    description="tkScenarist - screen writing made simpler",
    author="Raphaël SEBAN",
    author_email="motus@laposte.net",
    maintainer="Raphaël SEBAN",
    maintainer_email="motus@laposte.net",
    url="https://github.com/tarball69/tkScenarist/wiki",
    download_url="https://github.com/tarball69/tkScenarist/releases",
    keywords=["scenario", "scenarist", "script", "writer",
    "storyboard", "character", "movie"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Other Environment",
        "Environment :: MacOS X",
        "Environment :: Win32 (MS Windows)",
        "Environment :: X11 Applications",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Topic :: Artistic Software",
        "Topic :: Text Editors",
        "Topic :: Text Editors :: Documentation",
        "Topic :: Utilities",
    ],
    license="Licensed under GNU General Public License v3.",
    long_description="""

tkScenarist - screen writing made simpler
-----------------------------------------

**tkScenarist** is a simple Python3/Tkinter application aiming to make
movie screen writing simpler for scenarists.

**CAUTION**: minimum requirements are Python >= 3.3 with its dedicated
Tkinter GUI library (Tcl >= 8.5).

This software is a **freefullware** (see below).


What's new?
-----------

* Changed application's structure.


Freefullware
------------

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free;

Just get it and enjoy.

That's all, folks!


Documentation
-------------

Please, feel free to visit our wiki wiki online documentation at:

https://github.com/tarball69/tkScenarist/wiki

No answer in documentation? Request for help on our mailing list:

https://mail.python.org/mailman/listinfo/tkscenarist-help


MS-Windows users
----------------

MS-Windows users may find a `setup.exe` file at:

https://github.com/tarball69/tkScenarist/tree/master/win32setup

First, click on given file name/version then click on `Raw` button to
download it.

"""

) # end setup
